@@ -15,6 +15,7 @@ import shutil
 import honeybee_radiance_folder.config as config
 
 from .folderutil import parse_aperture_groups, parse_dynamic_scene, _nukedir
+from .gridutil import parse_grid_info, parse_grid_json
 
 try:
     from ConfigParser import SafeConfigParser as CP
@@ -500,6 +501,57 @@ class ModelFolder(_Folder):
         return self._dynamic_scene_indoor if indoor \
             else self._dynamic_scene
 
+    def grid_info(self, is_model=False):
+        """Parse the appropriate grids_info file to return high level information about
+        the sensor grids contained in the model folder.
+
+        Args:
+            is_model: If set to True, the _model_grids_info.json, which is
+                written out after simulations will be parsed. Else the _info.json will be
+                parsed. Defaults to False as the _info.json file is always expected to be
+                present.
+
+        Returns:
+            The list containing information about sensor grids that are written to the
+                folder after model export.
+        """
+        if is_model:
+            info_json = os.path.join(self.grid_folder(full=True),
+                                     '_model_grids_info.json')
+        else:
+            info_json = os.path.join(self.grid_folder(full=True), '_info.json')
+
+        return parse_grid_info(info_json)
+
+    def grid_data_all(self, info_from_model=False):
+        """ This is an internal function that for a specified info_json, returns the
+        consolidated grid data ,that includes grid names,counts and identifiers, as a
+        single dictionary.
+
+        Args:
+            info_from_model: If set to True, data will be retrieved using
+            _model_grids_info.json, which is written out after simulations.Else the
+            _info.json will be used. Defaults to False as the _info.json file is always
+            expected to be present.
+        Returns:
+            A dictionary containing consolidated grid data for the entire folder.
+        """
+
+        grid_info = self.grid_info(is_model=info_from_model)
+        grid_folder = self.grid_folder(full=True)
+
+        grid_data_dict = {}
+
+        if not grid_info:
+            return None
+        else:
+            for grid in grid_info:
+                grid_id = grid.pop('full_id')
+                grid_data_dict[grid_id] = parse_grid_json(
+                    os.path.join(grid_folder, grid_id + '.json'))
+                grid_data_dict[grid_id].update(grid)
+            return grid_data_dict
+
     def write(self, folder_type=0, cfg=None, overwrite=False):
         """Write an empty model folder.
 
